==> werkout-server-1.2.6.tgz: package/lib/helpers.js <==
const fs = require('fs-extra')
const path = require('path')

function createQuery (resourceType, constraints) {
  // Setup base query
  let query = {
    path: {
      startsWith: `/${resourceType}/`
    },
    valueField: {
      isAvailable: {
        equals: true
      }
    }
  }

  if (constraints) {
    // Set constraints in query
    Object.keys(constraints).forEach(constraintName => {
      Object.keys(constraints[constraintName]).forEach(predicate => {
        query.valueField[`metadata.${constraintName}.value`] = {
          [predicate]: constraints[constraintName][predicate]
        }
      })
    })
  }

  return query
}

function convertRequest (rawRequest) {
  const requestedResources = rawRequest.requestedResources
  // Check to see if request contains any requested resources
  if (requestedResources) {
    return {
      ...rawRequest,
      requestedResources: Object.keys(requestedResources).reduce(
        (acc, type) => {
          requestedResources[type].forEach(requestedResource => {
            acc.push({
              query: createQuery(type, requestedResource.constraints),
              resource: {
                type
              },
              isFulfilled: false
            })
          })
          return acc
        },
        []
      )
    }
  } else {
    throw new Error('No requested resources.')
  }
}

function loadUsers (peer) {
  // Read JSON file containing users
  return fs.readJson(path.join(__dirname, '../users.json')).then(users => {
    return users.map(user => {
      return peer.call('/werkout-server/methods/addResource', {
        type: 'users',
        data: {
          value: {
            ...user,
            isAvailable: true
          }
        }
      })
    })
  })
}

module.exports = {
  createQuery,
  convertRequest,
  loadUsers
}

==> werkout-server-1.4.0.tgz: package/lib/helpers.js <==
const fs = require('fs-extra')
const { logger } = require('./logger')

function createQuery (resourceType, constraints) {
  // Setup base query
  let query = {
    path: {
      startsWith: `/${resourceType}/`
    },
    valueField: {
      isAvailable: {
        equals: true
      }
    }
  }

  if (constraints) {
    // Set constraints in query
    Object.keys(constraints).forEach(constraintName => {
      Object.keys(constraints[constraintName]).forEach(predicate => {
        query.valueField[`metadata.${constraintName}.value`] = {
          [predicate]: constraints[constraintName][predicate]
        }
      })
    })
  }

  return query
}

function convertRequest (rawRequest) {
  const requestedResources = rawRequest.requestedResources
  // Check to see if request contains any requested resources
  if (requestedResources) {
    return {
      ...rawRequest,
      requestedResources: Object.keys(requestedResources).reduce(
        (acc, type) => {
          requestedResources[type].forEach(requestedResource => {
            acc.push({
              query: createQuery(type, requestedResource.constraints),
              resource: {
                type
              },
              isFulfilled: false
            })
          })
          return acc
        },
        []
      )
    }
  } else {
    throw new Error('No requested resources.')
  }
}

function loadUsers (peer, pathToUsers) {
  // Read JSON file containing users
  return fs
    .readJson(pathToUsers)
    .then(users => {
      return users.map(user => {
        return peer.call('/werkout-server/methods/addResource', {
          type: 'users',
          data: {
            value: {
              ...user,
              isAvailable: true
            }
          }
        })
      })
    })
    .catch(e => {
      logger.error(`Failed to load users from '${pathToUsers}'`)
      logger.error(e)
    })
}

module.exports = {
  createQuery,
  convertRequest,
  loadUsers
}
